==> qmmp_0.2.3.orig.tar.gz: qmmp-0.2.3/src/plugins/Input/wavpack/translations/wavpack_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS><TS version="1.1" language="pl">
<defaultcodec></defaultcodec>
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="28"/>
        <source>WavPack Plugin</source>
        <translation>Модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="30"/>
        <source>WavPack Files</source>
        <translation>Файлы WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="89"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Об аудио-модуле WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="90"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Аудио-модуль WavPack для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="92"/>
        <source>WavPack library version:</source>
        <translation>Версия библиотеки WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="93"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>кБ/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>кБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Путь к файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Информация WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Длительность:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Дискретизация:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Каналов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Битовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Сжатие:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Номер трека:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
</TS>

==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Input/wavpack/translations/wavpack_plugin_ru.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="pl">
<context>
    <name>DecoderWavPackFactory</name>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="44"/>
        <source>WavPack Plugin</source>
        <translation>Модуль WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="46"/>
        <source>WavPack Files</source>
        <translation>Файлы WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="129"/>
        <source>About WavPack Audio Plugin</source>
        <translation>Об аудио-модуле WavPack</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="130"/>
        <source>Qmmp WavPack Audio Plugin</source>
        <translation>Аудио-модуль WavPack для Qmmp</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="131"/>
        <source>WavPack library version:</source>
        <translation>Версия библиотеки WavPack:</translation>
    </message>
    <message>
        <location filename="../decoderwavpackfactory.cpp" line="133"/>
        <source>Writen by: Ilya Kotov &lt;forkotov02@hotmail.ru&gt;</source>
        <translation>Разработчик: Илья Котов &lt;forkotov02@hotmail.ru&gt;</translation>
    </message>
</context>
<context>
    <name>DetailsDialog</name>
    <message>
        <location filename="../detailsdialog.cpp" line="68"/>
        <source>Hz</source>
        <translation>Гц</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="73"/>
        <source>kbps</source>
        <translation>кБ/с</translation>
    </message>
    <message>
        <location filename="../detailsdialog.cpp" line="75"/>
        <source>KB</source>
        <translation>кБ</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="13"/>
        <source>Details</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="19"/>
        <source>File path:</source>
        <translation>Путь к файлу:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="42"/>
        <source>WavPack Info</source>
        <translation>Информация WavPack</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="48"/>
        <source>Length:</source>
        <translation>Длительность:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="58"/>
        <location filename="../detailsdialog.ui" line="75"/>
        <location filename="../detailsdialog.ui" line="92"/>
        <location filename="../detailsdialog.ui" line="118"/>
        <location filename="../detailsdialog.ui" line="135"/>
        <location filename="../detailsdialog.ui" line="152"/>
        <location filename="../detailsdialog.ui" line="169"/>
        <source>-</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="65"/>
        <source>Sample rate:</source>
        <translation>Дискретизация:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="82"/>
        <source>File size:</source>
        <translation>Размер файла:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="102"/>
        <source>Channels:</source>
        <translation>Каналов:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="125"/>
        <source>Bitrate:</source>
        <translation>Битовая частота:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="142"/>
        <source>Ratio:</source>
        <translation>Сжатие:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="159"/>
        <source>Version:</source>
        <translation>Версия:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="198"/>
        <source>APE Tag</source>
        <translation>APE-тег</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="225"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="235"/>
        <source>Track number:</source>
        <translation>Номер трека:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="248"/>
        <source>Year:</source>
        <translation>Год:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="258"/>
        <source>Genre:</source>
        <translation>Жанр:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="268"/>
        <source>Comment:</source>
        <translation>Комментарий:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="278"/>
        <source>Album:</source>
        <translation>Альбом:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="288"/>
        <source>Artist:</source>
        <translation>Исполнитель:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="298"/>
        <source>Title:</source>
        <translation>Название:</translation>
    </message>
    <message>
        <location filename="../detailsdialog.ui" line="339"/>
        <source>Close</source>
        <translation>Закрыть</translation>
    </message>
</context>
</TS>
